/* Non Linear Systems */
#include "Solar_model.h"
#include "Solar_12jac.h"
#if defined(__cplusplus)
extern "C" {
#endif

/* inner equations */

/*
equation index: 15
type: SIMPLE_ASSIGN
solarCollector.WRadGlass[1] = 5.67e-08 * solarCollector.F12 * solarCollector.AGlass * solarCollector.EpsGlass * (solarCollector.Tglass[1] ^ 4.0 - solarCollector.Tsky ^ 4.0)
*/
void Solar_eqFunction_15(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,15};
  modelica_real tmp0;
  modelica_real tmp1;
  tmp0 = (data->localData[0]->realVars[1]/* solarCollector.Tglass[1] STATE(1) */) ;
  tmp0 *= tmp0;tmp1 = (data->localData[0]->realVars[15]/* solarCollector.Tsky variable */) ;
  tmp1 *= tmp1;
  (data->localData[0]->realVars[21]/* solarCollector.WRadGlass[1] variable */)  = (5.67e-08) * (((data->simulationInfo->realParameter[32]/* solarCollector.F12 PARAM */) ) * (((data->localData[0]->realVars[9]/* solarCollector.AGlass variable */) ) * (((data->simulationInfo->realParameter[30]/* solarCollector.EpsGlass PARAM */) ) * ((tmp0 * tmp0) - ((tmp1 * tmp1))))));
  TRACE_POP
}
/*
equation index: 16
type: SIMPLE_ASSIGN
solarCollector.WConvGlass[1] = solarCollector.AGlass * solarCollector.h * (solarCollector.Tglass[1] - T_atm.k)
*/
void Solar_eqFunction_16(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,16};
  (data->localData[0]->realVars[19]/* solarCollector.WConvGlass[1] variable */)  = ((data->localData[0]->realVars[9]/* solarCollector.AGlass variable */) ) * (((data->simulationInfo->realParameter[48]/* solarCollector.h PARAM */) ) * ((data->localData[0]->realVars[1]/* solarCollector.Tglass[1] STATE(1) */)  - (data->simulationInfo->realParameter[16]/* T_atm.k PARAM */) ));
  TRACE_POP
}
/*
equation index: 17
type: SIMPLE_ASSIGN
solarCollector.WTube[1] = -(solarCollector.OptEff * radiation.k * solarCollector.AReflector + (-solarCollector.WRadGlass[1]) - solarCollector.WConvGlass[1])
*/
void Solar_eqFunction_17(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,17};
  (data->localData[0]->realVars[23]/* solarCollector.WTube[1] variable */)  = (-(((data->localData[0]->realVars[13]/* solarCollector.OptEff variable */) ) * (((data->simulationInfo->realParameter[23]/* radiation.k PARAM */) ) * ((data->localData[0]->realVars[10]/* solarCollector.AReflector variable */) )) + (-(data->localData[0]->realVars[21]/* solarCollector.WRadGlass[1] variable */) ) - (data->localData[0]->realVars[19]/* solarCollector.WConvGlass[1] variable */) ));
  TRACE_POP
}
/*
equation index: 18
type: SIMPLE_ASSIGN
$outputAlias_heatFlow = (-solarCollector.WTube[1]) - Paroi3.dM * Paroi3.cpw * $DER.Paroi3.Tp[1]
*/
void Solar_eqFunction_18(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,18};
  (data->localData[0]->realVars[0]/* $outputAlias_heatFlow STATE(1,$heatFlow_der) */)  = (-(data->localData[0]->realVars[23]/* solarCollector.WTube[1] variable */) ) - (((data->simulationInfo->realParameter[10]/* Paroi3.dM PARAM */) ) * (((data->simulationInfo->realParameter[9]/* Paroi3.cpw PARAM */) ) * ((data->localData[0]->realVars[4]/* der(Paroi3.Tp[1]) DUMMY_DER */) )));
  TRACE_POP
}
/*
equation index: 19
type: SIMPLE_ASSIGN
Paroi3.Tp[1] = (heatSource.T0[1] / log(1.0 + Paroi3.e / Paroi3.D) * Paroi3.lambda * Paroi3.ntubes * Paroi3.dx * 6.283185307179586 + $outputAlias_heatFlow) * log(1.0 + Paroi3.e / Paroi3.D) / (6.283185307179586 * Paroi3.dx * Paroi3.ntubes * Paroi3.lambda)
*/
void Solar_eqFunction_19(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,19};
  modelica_real tmp0;
  modelica_real tmp1;
  tmp0 = 1.0 + DIVISION_SIM((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) ,(data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) ,"Paroi3.D",equationIndexes);
  if(!(tmp0 > 0.0))
  {
    if (data->simulationInfo->noThrowAsserts) {
      infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      data->simulationInfo->needToReThrow = 1;
    } else {
      FILE_INFO info = {"",0,0,0,0,0};
      omc_assert_warning(info, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      throwStreamPrintWithEquationIndexes(threadData, equationIndexes, "Model error: Argument of log(1.0 + Paroi3.e / Paroi3.D) was %g should be > 0", tmp0);
    }
  }tmp1 = 1.0 + DIVISION_SIM((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) ,(data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) ,"Paroi3.D",equationIndexes);
  if(!(tmp1 > 0.0))
  {
    if (data->simulationInfo->noThrowAsserts) {
      infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      data->simulationInfo->needToReThrow = 1;
    } else {
      FILE_INFO info = {"",0,0,0,0,0};
      omc_assert_warning(info, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      throwStreamPrintWithEquationIndexes(threadData, equationIndexes, "Model error: Argument of log(1.0 + Paroi3.e / Paroi3.D) was %g should be > 0", tmp1);
    }
  }
  (data->localData[0]->realVars[6]/* Paroi3.Tp[1] DUMMY_STATE */)  = DIVISION_SIM((((((DIVISION_SIM((data->simulationInfo->realParameter[21]/* heatSource.T0[1] PARAM */) ,log(tmp0),"log(1.0 + Paroi3.e / Paroi3.D)",equationIndexes)) * ((data->simulationInfo->realParameter[13]/* Paroi3.lambda PARAM */) )) * ((data->simulationInfo->realParameter[14]/* Paroi3.ntubes PARAM */) )) * ((data->simulationInfo->realParameter[11]/* Paroi3.dx PARAM */) )) * (6.283185307179586) + (data->localData[0]->realVars[0]/* $outputAlias_heatFlow STATE(1,$heatFlow_der) */) ) * (log(tmp1)),(((6.283185307179586) * ((data->simulationInfo->realParameter[11]/* Paroi3.dx PARAM */) )) * ((data->simulationInfo->realParameter[14]/* Paroi3.ntubes PARAM */) )) * ((data->simulationInfo->realParameter[13]/* Paroi3.lambda PARAM */) ),"6.283185307179586 * Paroi3.dx * Paroi3.ntubes * Paroi3.lambda",equationIndexes);
  TRACE_POP
}
/*
equation index: 20
type: SIMPLE_ASSIGN
solarCollector.Twall[1] = ((-Paroi3.lambda) * Paroi3.Tp[1] / log(1.0 + Paroi3.e / (Paroi3.e + Paroi3.D)) * Paroi3.ntubes * Paroi3.dx * 6.283185307179586 + solarCollector.WTube[1]) * log(1.0 + Paroi3.e / (Paroi3.e + Paroi3.D)) / ((-6.283185307179586) * Paroi3.dx * Paroi3.ntubes * Paroi3.lambda)
*/
void Solar_eqFunction_20(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,20};
  modelica_real tmp0;
  modelica_real tmp1;
  tmp0 = 1.0 + DIVISION_SIM((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) ,(data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */)  + (data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) ,"Paroi3.e + Paroi3.D",equationIndexes);
  if(!(tmp0 > 0.0))
  {
    if (data->simulationInfo->noThrowAsserts) {
      infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      data->simulationInfo->needToReThrow = 1;
    } else {
      FILE_INFO info = {"",0,0,0,0,0};
      omc_assert_warning(info, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      throwStreamPrintWithEquationIndexes(threadData, equationIndexes, "Model error: Argument of log(1.0 + Paroi3.e / (Paroi3.e + Paroi3.D)) was %g should be > 0", tmp0);
    }
  }tmp1 = 1.0 + DIVISION_SIM((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) ,(data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */)  + (data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) ,"Paroi3.e + Paroi3.D",equationIndexes);
  if(!(tmp1 > 0.0))
  {
    if (data->simulationInfo->noThrowAsserts) {
      infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      data->simulationInfo->needToReThrow = 1;
    } else {
      FILE_INFO info = {"",0,0,0,0,0};
      omc_assert_warning(info, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      throwStreamPrintWithEquationIndexes(threadData, equationIndexes, "Model error: Argument of log(1.0 + Paroi3.e / (Paroi3.e + Paroi3.D)) was %g should be > 0", tmp1);
    }
  }
  (data->localData[0]->realVars[16]/* solarCollector.Twall[1] variable */)  = DIVISION_SIM(((((DIVISION_SIM(((-(data->simulationInfo->realParameter[13]/* Paroi3.lambda PARAM */) )) * ((data->localData[0]->realVars[6]/* Paroi3.Tp[1] DUMMY_STATE */) ),log(tmp0),"log(1.0 + Paroi3.e / (Paroi3.e + Paroi3.D))",equationIndexes)) * ((data->simulationInfo->realParameter[14]/* Paroi3.ntubes PARAM */) )) * ((data->simulationInfo->realParameter[11]/* Paroi3.dx PARAM */) )) * (6.283185307179586) + (data->localData[0]->realVars[23]/* solarCollector.WTube[1] variable */) ) * (log(tmp1)),(((-6.283185307179586) * ((data->simulationInfo->realParameter[11]/* Paroi3.dx PARAM */) )) * ((data->simulationInfo->realParameter[14]/* Paroi3.ntubes PARAM */) )) * ((data->simulationInfo->realParameter[13]/* Paroi3.lambda PARAM */) ),"(-6.283185307179586) * Paroi3.dx * Paroi3.ntubes * Paroi3.lambda",equationIndexes);
  TRACE_POP
}
/*
equation index: 21
type: SIMPLE_ASSIGN
solarCollector.WRadWall[1] = 5.67e-08 * solarCollector.ATube * solarCollector.EpsTube * (solarCollector.Twall[1] ^ 4.0 - solarCollector.Tglass[1] ^ 4.0)
*/
void Solar_eqFunction_21(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,21};
  modelica_real tmp0;
  modelica_real tmp1;
  tmp0 = (data->localData[0]->realVars[16]/* solarCollector.Twall[1] variable */) ;
  tmp0 *= tmp0;tmp1 = (data->localData[0]->realVars[1]/* solarCollector.Tglass[1] STATE(1) */) ;
  tmp1 *= tmp1;
  (data->localData[0]->realVars[22]/* solarCollector.WRadWall[1] variable */)  = (5.67e-08) * (((data->localData[0]->realVars[11]/* solarCollector.ATube variable */) ) * (((data->simulationInfo->realParameter[31]/* solarCollector.EpsTube PARAM */) ) * ((tmp0 * tmp0) - ((tmp1 * tmp1)))));
  TRACE_POP
}
/*
equation index: 22
type: SIMPLE_ASSIGN
solarCollector.WCondWall[1] = 2.0 * solarCollector.ATube * solarCollector.Lambda * (solarCollector.Twall[1] - solarCollector.Tglass[1]) / (log(solarCollector.DGlass / solarCollector.DTube) * solarCollector.DTube)
*/
void Solar_eqFunction_22(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,22};
  modelica_real tmp0;
  tmp0 = DIVISION_SIM((data->simulationInfo->realParameter[28]/* solarCollector.DGlass PARAM */) ,(data->simulationInfo->realParameter[29]/* solarCollector.DTube PARAM */) ,"solarCollector.DTube",equationIndexes);
  if(!(tmp0 > 0.0))
  {
    if (data->simulationInfo->noThrowAsserts) {
      infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      data->simulationInfo->needToReThrow = 1;
    } else {
      FILE_INFO info = {"",0,0,0,0,0};
      omc_assert_warning(info, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      throwStreamPrintWithEquationIndexes(threadData, equationIndexes, "Model error: Argument of log(solarCollector.DGlass / solarCollector.DTube) was %g should be > 0", tmp0);
    }
  }
  (data->localData[0]->realVars[18]/* solarCollector.WCondWall[1] variable */)  = (2.0) * (((data->localData[0]->realVars[11]/* solarCollector.ATube variable */) ) * (((data->simulationInfo->realParameter[37]/* solarCollector.Lambda PARAM */) ) * (DIVISION_SIM((data->localData[0]->realVars[16]/* solarCollector.Twall[1] variable */)  - (data->localData[0]->realVars[1]/* solarCollector.Tglass[1] STATE(1) */) ,(log(tmp0)) * ((data->simulationInfo->realParameter[29]/* solarCollector.DTube PARAM */) ),"log(solarCollector.DGlass / solarCollector.DTube) * solarCollector.DTube",equationIndexes))));
  TRACE_POP
}

void residualFunc35(void** dataIn, const double* xloc, double* res, const int* iflag)
{
  TRACE_PUSH
  DATA *data = (DATA*) ((void**)dataIn[0]);
  threadData_t *threadData = (threadData_t*) ((void**)dataIn[1]);
  const int equationIndexes[2] = {1,35};
  int i;
  /* iteration variables */
  for (i=0; i<1; i++) {
    if (isinf(xloc[i]) || isnan(xloc[i])) {
      for (i=0; i<1; i++) {
        res[i] = NAN;
      }
      return;
    }
  }
  (data->localData[0]->realVars[1]/* solarCollector.Tglass[1] STATE(1) */)  = xloc[0];
  /* backup outputs */
  /* pre body */
  /* local constraints */
  Solar_eqFunction_15(data, threadData);

  /* local constraints */
  Solar_eqFunction_16(data, threadData);

  /* local constraints */
  Solar_eqFunction_17(data, threadData);

  /* local constraints */
  Solar_eqFunction_18(data, threadData);

  /* local constraints */
  Solar_eqFunction_19(data, threadData);

  /* local constraints */
  Solar_eqFunction_20(data, threadData);

  /* local constraints */
  Solar_eqFunction_21(data, threadData);

  /* local constraints */
  Solar_eqFunction_22(data, threadData);
  /* body */
  res[0] = (data->localData[0]->realVars[22]/* solarCollector.WRadWall[1] variable */)  + (data->localData[0]->realVars[18]/* solarCollector.WCondWall[1] variable */)  + (data->localData[0]->realVars[17]/* solarCollector.WAbsGlass[1] variable */)  - (((data->localData[0]->realVars[24]/* solarCollector.dM variable */) ) * (((data->simulationInfo->realParameter[45]/* solarCollector.cp_glass PARAM */) ) * ((data->localData[0]->realVars[3]/* der(solarCollector.Tglass[1]) STATE_DER */) ))) - (data->localData[0]->realVars[19]/* solarCollector.WConvGlass[1] variable */)  - (data->localData[0]->realVars[21]/* solarCollector.WRadGlass[1] variable */) ;
  /* restore known outputs */
  TRACE_POP
}

OMC_DISABLE_OPT
void initializeSparsePatternNLS35(NONLINEAR_SYSTEM_DATA* inSysData)
{
  int i=0;
  const int colPtrIndex[1+1] = {0,1};
  const int rowIndex[1] = {0};
  /* sparsity pattern available */
  inSysData->isPatternAvailable = 'T';
  inSysData->sparsePattern = (SPARSE_PATTERN*) malloc(sizeof(SPARSE_PATTERN));
  inSysData->sparsePattern->leadindex = (unsigned int*) malloc((1+1)*sizeof(unsigned int));
  inSysData->sparsePattern->index = (unsigned int*) malloc(1*sizeof(unsigned int));
  inSysData->sparsePattern->numberOfNonZeros = 1;
  inSysData->sparsePattern->colorCols = (unsigned int*) malloc(1*sizeof(unsigned int));
  inSysData->sparsePattern->maxColors = 1;
  
  /* write lead index of compressed sparse column */
  memcpy(inSysData->sparsePattern->leadindex, colPtrIndex, (1+1)*sizeof(unsigned int));
  
  for(i=2;i<1+1;++i)
    inSysData->sparsePattern->leadindex[i] += inSysData->sparsePattern->leadindex[i-1];
  
  /* call sparse index */
  memcpy(inSysData->sparsePattern->index, rowIndex, 1*sizeof(unsigned int));
  
  /* write color array */
  inSysData->sparsePattern->colorCols[0] = 1;
}

OMC_DISABLE_OPT
void initializeStaticDataNLS35(void *inData, threadData_t *threadData, void *inSystemData)
{
  DATA* data = (DATA*) inData;
  NONLINEAR_SYSTEM_DATA* sysData = (NONLINEAR_SYSTEM_DATA*) inSystemData;
  int i=0;
  /* static nls data for solarCollector.Tglass[1] */
  sysData->nominal[i] = data->modelData->realVarsData[1].attribute /* solarCollector.Tglass[1] */.nominal;
  sysData->min[i]     = data->modelData->realVarsData[1].attribute /* solarCollector.Tglass[1] */.min;
  sysData->max[i++]   = data->modelData->realVarsData[1].attribute /* solarCollector.Tglass[1] */.max;
  /* initial sparse pattern */
  initializeSparsePatternNLS35(sysData);
}

OMC_DISABLE_OPT
void getIterationVarsNLS35(struct DATA *inData, double *array)
{
  DATA* data = (DATA*) inData;
  array[0] = (data->localData[0]->realVars[1]/* solarCollector.Tglass[1] STATE(1) */) ;
}

/* Prototypes for the strict sets (Dynamic Tearing) */

/* Global constraints for the casual sets */
/* function initialize non-linear systems */
void Solar_initialNonLinearSystem(int nNonLinearSystems, NONLINEAR_SYSTEM_DATA* nonLinearSystemData)
{
  
  nonLinearSystemData[0].equationIndex = 35;
  nonLinearSystemData[0].size = 1;
  nonLinearSystemData[0].homotopySupport = 0;
  nonLinearSystemData[0].mixedSystem = 0;
  nonLinearSystemData[0].residualFunc = residualFunc35;
  nonLinearSystemData[0].strictTearingFunctionCall = NULL;
  nonLinearSystemData[0].analyticalJacobianColumn = Solar_functionJacNLSJac0_column;
  nonLinearSystemData[0].initialAnalyticalJacobian = Solar_initialAnalyticJacobianNLSJac0;
  nonLinearSystemData[0].jacobianIndex = 0 /*jacInx*/;
  nonLinearSystemData[0].initializeStaticNLSData = initializeStaticDataNLS35;
  nonLinearSystemData[0].getIterationVars = getIterationVarsNLS35;
  nonLinearSystemData[0].checkConstraints = NULL;
}

#if defined(__cplusplus)
}
#endif

