/* update bound parameters and variable attributes (start, nominal, min, max) */
#include "Solar_model.h"
#if defined(__cplusplus)
extern "C" {
#endif

OMC_DISABLE_OPT
int Solar_updateBoundVariableAttributes(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  /* min ******************************************************** */
  
  infoStreamPrint(LOG_INIT, 1, "updating min-values");
  if (ACTIVE_STREAM(LOG_INIT)) messageClose(LOG_INIT);
  
  /* max ******************************************************** */
  
  infoStreamPrint(LOG_INIT, 1, "updating max-values");
  if (ACTIVE_STREAM(LOG_INIT)) messageClose(LOG_INIT);
  
  /* nominal **************************************************** */
  
  infoStreamPrint(LOG_INIT, 1, "updating nominal-values");
  if (ACTIVE_STREAM(LOG_INIT)) messageClose(LOG_INIT);
  
  /* start ****************************************************** */
  infoStreamPrint(LOG_INIT, 1, "updating primary start-values");
  if (ACTIVE_STREAM(LOG_INIT)) messageClose(LOG_INIT);
  
  TRACE_POP
  return 0;
}

void Solar_updateBoundParameters_0(DATA *data, threadData_t *threadData);

/*
equation index: 52
type: SIMPLE_ASSIGN
$cse4 = log(1.0 + Paroi3.e / (Paroi3.e + Paroi3.D))
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_52(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,52};
  modelica_real tmp0;
  tmp0 = 1.0 + DIVISION_SIM((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) ,(data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */)  + (data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) ,"Paroi3.e + Paroi3.D",equationIndexes);
  if(!(tmp0 > 0.0))
  {
    if (data->simulationInfo->noThrowAsserts) {
      infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      data->simulationInfo->needToReThrow = 1;
    } else {
      FILE_INFO info = {"",0,0,0,0,0};
      omc_assert_warning(info, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      throwStreamPrintWithEquationIndexes(threadData, equationIndexes, "Model error: Argument of log(1.0 + Paroi3.e / (Paroi3.e + Paroi3.D)) was %g should be > 0", tmp0);
    }
  }
  (data->simulationInfo->realParameter[0]/* $cse4 PARAM */)  = log(tmp0);
  TRACE_POP
}

/*
equation index: 53
type: SIMPLE_ASSIGN
$cse5 = log(1.0 + Paroi3.e / Paroi3.D)
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_53(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,53};
  modelica_real tmp1;
  tmp1 = 1.0 + DIVISION_SIM((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) ,(data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) ,"Paroi3.D",equationIndexes);
  if(!(tmp1 > 0.0))
  {
    if (data->simulationInfo->noThrowAsserts) {
      infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      data->simulationInfo->needToReThrow = 1;
    } else {
      FILE_INFO info = {"",0,0,0,0,0};
      omc_assert_warning(info, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      throwStreamPrintWithEquationIndexes(threadData, equationIndexes, "Model error: Argument of log(1.0 + Paroi3.e / Paroi3.D) was %g should be > 0", tmp1);
    }
  }
  (data->simulationInfo->realParameter[1]/* $cse5 PARAM */)  = log(tmp1);
  TRACE_POP
}

/*
equation index: 54
type: SIMPLE_ASSIGN
$cse6 = log(solarCollector.DGlass / solarCollector.DTube)
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_54(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,54};
  modelica_real tmp2;
  tmp2 = DIVISION_SIM((data->simulationInfo->realParameter[28]/* solarCollector.DGlass PARAM */) ,(data->simulationInfo->realParameter[29]/* solarCollector.DTube PARAM */) ,"solarCollector.DTube",equationIndexes);
  if(!(tmp2 > 0.0))
  {
    if (data->simulationInfo->noThrowAsserts) {
      infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      data->simulationInfo->needToReThrow = 1;
    } else {
      FILE_INFO info = {"",0,0,0,0,0};
      omc_assert_warning(info, "The following assertion has been violated %sat time %f", initial() ? "during initialization " : "", data->localData[0]->timeValue);
      throwStreamPrintWithEquationIndexes(threadData, equationIndexes, "Model error: Argument of log(solarCollector.DGlass / solarCollector.DTube) was %g should be > 0", tmp2);
    }
  }
  (data->simulationInfo->realParameter[2]/* $cse6 PARAM */)  = log(tmp2);
  TRACE_POP
}

/*
equation index: 55
type: SIMPLE_ASSIGN
solarCollector.Tatm = T_atm.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_55(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,55};
  (data->simulationInfo->realParameter[42]/* solarCollector.Tatm PARAM */)  = (data->simulationInfo->realParameter[16]/* T_atm.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 56
type: SIMPLE_ASSIGN
solarCollector.AtmTemp.signal = T_atm.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_56(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,56};
  (data->simulationInfo->realParameter[27]/* solarCollector.AtmTemp.signal PARAM */)  = (data->simulationInfo->realParameter[16]/* T_atm.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 57
type: SIMPLE_ASSIGN
T_atm.y.signal = T_atm.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_57(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,57};
  (data->simulationInfo->realParameter[17]/* T_atm.y.signal PARAM */)  = (data->simulationInfo->realParameter[16]/* T_atm.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 58
type: SIMPLE_ASSIGN
solarCollector.PhiSun = radiation.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_58(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,58};
  (data->simulationInfo->realParameter[38]/* solarCollector.PhiSun PARAM */)  = (data->simulationInfo->realParameter[23]/* radiation.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 59
type: SIMPLE_ASSIGN
solarCollector.ISun.signal = radiation.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_59(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,59};
  (data->simulationInfo->realParameter[34]/* solarCollector.ISun.signal PARAM */)  = (data->simulationInfo->realParameter[23]/* radiation.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 60
type: SIMPLE_ASSIGN
radiation.y.signal = radiation.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_60(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,60};
  (data->simulationInfo->realParameter[24]/* radiation.y.signal PARAM */)  = (data->simulationInfo->realParameter[23]/* radiation.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 61
type: SIMPLE_ASSIGN
solarCollector.Theta = angle_incidence.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_61(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,61};
  (data->simulationInfo->realParameter[44]/* solarCollector.Theta PARAM */)  = (data->simulationInfo->realParameter[18]/* angle_incidence.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 62
type: SIMPLE_ASSIGN
solarCollector.IncidenceAngle.signal = angle_incidence.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_62(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,62};
  (data->simulationInfo->realParameter[35]/* solarCollector.IncidenceAngle.signal PARAM */)  = (data->simulationInfo->realParameter[18]/* angle_incidence.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 63
type: SIMPLE_ASSIGN
angle_incidence.y.signal = angle_incidence.k
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_63(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,63};
  (data->simulationInfo->realParameter[19]/* angle_incidence.y.signal PARAM */)  = (data->simulationInfo->realParameter[18]/* angle_incidence.k PARAM */) ;
  TRACE_POP
}

/*
equation index: 64
type: SIMPLE_ASSIGN
Paroi3.Tp1[1] = heatSource.T0[1]
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_64(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,64};
  (data->simulationInfo->realParameter[7]/* Paroi3.Tp1[1] PARAM */)  = (data->simulationInfo->realParameter[21]/* heatSource.T0[1] PARAM */) ;
  TRACE_POP
}

/*
equation index: 65
type: SIMPLE_ASSIGN
Paroi3.WT1[1].T = heatSource.T0[1]
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_65(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,65};
  (data->simulationInfo->realParameter[8]/* Paroi3.WT1[1].T PARAM */)  = (data->simulationInfo->realParameter[21]/* heatSource.T0[1] PARAM */) ;
  TRACE_POP
}

/*
equation index: 66
type: SIMPLE_ASSIGN
heatSource.C[1].T = heatSource.T0[1]
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_66(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,66};
  (data->simulationInfo->realParameter[20]/* heatSource.C[1].T PARAM */)  = (data->simulationInfo->realParameter[21]/* heatSource.T0[1] PARAM */) ;
  TRACE_POP
}

/*
equation index: 69
type: SIMPLE_ASSIGN
Paroi3.L = L
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_69(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,69};
  (data->simulationInfo->realParameter[5]/* Paroi3.L PARAM */)  = (data->simulationInfo->realParameter[3]/* L PARAM */) ;
  TRACE_POP
}

/*
equation index: 70
type: SIMPLE_ASSIGN
Paroi3.dx = Paroi3.L
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_70(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,70};
  (data->simulationInfo->realParameter[11]/* Paroi3.dx PARAM */)  = (data->simulationInfo->realParameter[5]/* Paroi3.L PARAM */) ;
  TRACE_POP
}

/*
equation index: 71
type: SIMPLE_ASSIGN
Paroi3.dM = 0.7853981633974483 * Paroi3.ntubes * Paroi3.rhow * ((Paroi3.D + 2.0 * Paroi3.e) ^ 2.0 - Paroi3.D ^ 2.0) * Paroi3.dx
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_71(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,71};
  modelica_real tmp3;
  modelica_real tmp4;
  tmp3 = (data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */)  + (2.0) * ((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) );
  tmp4 = (data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) ;
  (data->simulationInfo->realParameter[10]/* Paroi3.dM PARAM */)  = (0.7853981633974483) * (((data->simulationInfo->realParameter[14]/* Paroi3.ntubes PARAM */) ) * (((data->simulationInfo->realParameter[15]/* Paroi3.rhow PARAM */) ) * (((tmp3 * tmp3) - ((tmp4 * tmp4))) * ((data->simulationInfo->realParameter[11]/* Paroi3.dx PARAM */) ))));
  TRACE_POP
}

/*
equation index: 76
type: SIMPLE_ASSIGN
solarCollector.L = L
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_76(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,76};
  (data->simulationInfo->realParameter[36]/* solarCollector.L PARAM */)  = (data->simulationInfo->realParameter[3]/* L PARAM */) ;
  TRACE_POP
}
extern void Solar_eqFunction_37(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_8(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_7(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_6(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_5(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_4(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_3(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_2(DATA *data, threadData_t *threadData);

extern void Solar_eqFunction_1(DATA *data, threadData_t *threadData);


/*
equation index: 87
type: ALGORITHM

  assert(Paroi3.D >= 0.0, "Variable violating min constraint: 0.0 <= Paroi3.D, has value: " + String(Paroi3.D, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_87(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,87};
  modelica_boolean tmp5;
  static const MMC_DEFSTRINGLIT(tmp6,63,"Variable violating min constraint: 0.0 <= Paroi3.D, has value: ");
  modelica_string tmp7;
  modelica_metatype tmpMeta8;
  static int tmp9 = 0;
  if(!tmp9)
  {
    tmp5 = GreaterEq((data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) ,0.0);
    if(!tmp5)
    {
      tmp7 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[4]/* Paroi3.D PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta8 = stringAppend(MMC_REFSTRINGLIT(tmp6),tmp7);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nParoi3.D >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta8));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/HeatTransfer/HeatExchangerWall.mo",4,3,4,69,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nParoi3.D >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta8));
        }
      }
      tmp9 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 88
type: ALGORITHM

  assert(Paroi3.e >= 0.0, "Variable violating min constraint: 0.0 <= Paroi3.e, has value: " + String(Paroi3.e, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_88(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,88};
  modelica_boolean tmp10;
  static const MMC_DEFSTRINGLIT(tmp11,63,"Variable violating min constraint: 0.0 <= Paroi3.e, has value: ");
  modelica_string tmp12;
  modelica_metatype tmpMeta13;
  static int tmp14 = 0;
  if(!tmp14)
  {
    tmp10 = GreaterEq((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) ,0.0);
    if(!tmp10)
    {
      tmp12 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[12]/* Paroi3.e PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta13 = stringAppend(MMC_REFSTRINGLIT(tmp11),tmp12);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nParoi3.e >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta13));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/HeatTransfer/HeatExchangerWall.mo",5,3,5,64,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nParoi3.e >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta13));
        }
      }
      tmp14 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 89
type: ALGORITHM

  assert(solarCollector.DTube >= 0.0, "Variable violating min constraint: 0.0 <= solarCollector.DTube, has value: " + String(solarCollector.DTube, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_89(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,89};
  modelica_boolean tmp15;
  static const MMC_DEFSTRINGLIT(tmp16,75,"Variable violating min constraint: 0.0 <= solarCollector.DTube, has value: ");
  modelica_string tmp17;
  modelica_metatype tmpMeta18;
  static int tmp19 = 0;
  if(!tmp19)
  {
    tmp15 = GreaterEq((data->simulationInfo->realParameter[29]/* solarCollector.DTube PARAM */) ,0.0);
    if(!tmp15)
    {
      tmp17 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[29]/* solarCollector.DTube PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta18 = stringAppend(MMC_REFSTRINGLIT(tmp16),tmp17);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nsolarCollector.DTube >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta18));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Solar/Collectors/SolarCollector.mo",7,3,7,64,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nsolarCollector.DTube >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta18));
        }
      }
      tmp19 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 90
type: ALGORITHM

  assert(solarCollector.DGlass >= 0.0, "Variable violating min constraint: 0.0 <= solarCollector.DGlass, has value: " + String(solarCollector.DGlass, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_90(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,90};
  modelica_boolean tmp20;
  static const MMC_DEFSTRINGLIT(tmp21,76,"Variable violating min constraint: 0.0 <= solarCollector.DGlass, has value: ");
  modelica_string tmp22;
  modelica_metatype tmpMeta23;
  static int tmp24 = 0;
  if(!tmp24)
  {
    tmp20 = GreaterEq((data->simulationInfo->realParameter[28]/* solarCollector.DGlass PARAM */) ,0.0);
    if(!tmp20)
    {
      tmp22 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[28]/* solarCollector.DGlass PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta23 = stringAppend(MMC_REFSTRINGLIT(tmp21),tmp22);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nsolarCollector.DGlass >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta23));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Solar/Collectors/SolarCollector.mo",8,3,8,67,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nsolarCollector.DGlass >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta23));
        }
      }
      tmp24 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 91
type: ALGORITHM

  assert(solarCollector.Tatm >= 0.0, "Variable violating min constraint: 0.0 <= solarCollector.Tatm, has value: " + String(solarCollector.Tatm, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_91(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,91};
  modelica_boolean tmp25;
  static const MMC_DEFSTRINGLIT(tmp26,74,"Variable violating min constraint: 0.0 <= solarCollector.Tatm, has value: ");
  modelica_string tmp27;
  modelica_metatype tmpMeta28;
  static int tmp29 = 0;
  if(!tmp29)
  {
    tmp25 = GreaterEq((data->simulationInfo->realParameter[42]/* solarCollector.Tatm PARAM */) ,0.0);
    if(!tmp25)
    {
      tmp27 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[42]/* solarCollector.Tatm PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta28 = stringAppend(MMC_REFSTRINGLIT(tmp26),tmp27);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nsolarCollector.Tatm >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta28));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Solar/Collectors/SolarCollector.mo",39,3,39,73,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nsolarCollector.Tatm >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta28));
        }
      }
      tmp29 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 92
type: ALGORITHM

  assert(heatSource.T0[1] >= 0.0, "Variable violating min constraint: 0.0 <= heatSource.T0[1], has value: " + String(heatSource.T0[1], "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_92(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,92};
  modelica_boolean tmp30;
  static const MMC_DEFSTRINGLIT(tmp31,71,"Variable violating min constraint: 0.0 <= heatSource.T0[1], has value: ");
  modelica_string tmp32;
  modelica_metatype tmpMeta33;
  static int tmp34 = 0;
  if(!tmp34)
  {
    tmp30 = GreaterEq((data->simulationInfo->realParameter[21]/* heatSource.T0[1] PARAM */) ,0.0);
    if(!tmp30)
    {
      tmp32 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[21]/* heatSource.T0[1] PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta33 = stringAppend(MMC_REFSTRINGLIT(tmp31),tmp32);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nheatSource.T0[1] >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta33));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/BoundaryConditions/HeatSource.mo",3,3,4,58,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nheatSource.T0[1] >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta33));
        }
      }
      tmp34 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 93
type: ALGORITHM

  assert(Paroi3.Tp1[1] >= 0.0, "Variable violating min constraint: 0.0 <= Paroi3.Tp1[1], has value: " + String(Paroi3.Tp1[1], "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_93(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,93};
  modelica_boolean tmp35;
  static const MMC_DEFSTRINGLIT(tmp36,68,"Variable violating min constraint: 0.0 <= Paroi3.Tp1[1], has value: ");
  modelica_string tmp37;
  modelica_metatype tmpMeta38;
  static int tmp39 = 0;
  if(!tmp39)
  {
    tmp35 = GreaterEq((data->simulationInfo->realParameter[7]/* Paroi3.Tp1[1] PARAM */) ,0.0);
    if(!tmp35)
    {
      tmp37 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[7]/* Paroi3.Tp1[1] PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta38 = stringAppend(MMC_REFSTRINGLIT(tmp36),tmp37);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nParoi3.Tp1[1] >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta38));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/HeatTransfer/HeatExchangerWall.mo",29,3,30,46,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nParoi3.Tp1[1] >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta38));
        }
      }
      tmp39 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 94
type: ALGORITHM

  assert(Paroi3.WT1[1].T >= 0.0, "Variable violating min constraint: 0.0 <= Paroi3.WT1[1].T, has value: " + String(Paroi3.WT1[1].T, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_94(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,94};
  modelica_boolean tmp40;
  static const MMC_DEFSTRINGLIT(tmp41,70,"Variable violating min constraint: 0.0 <= Paroi3.WT1[1].T, has value: ");
  modelica_string tmp42;
  modelica_metatype tmpMeta43;
  static int tmp44 = 0;
  if(!tmp44)
  {
    tmp40 = GreaterEq((data->simulationInfo->realParameter[8]/* Paroi3.WT1[1].T PARAM */) ,0.0);
    if(!tmp40)
    {
      tmp42 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[8]/* Paroi3.WT1[1].T PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta43 = stringAppend(MMC_REFSTRINGLIT(tmp41),tmp42);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nParoi3.WT1[1].T >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta43));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/Connectors.mo",4,5,4,49,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nParoi3.WT1[1].T >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta43));
        }
      }
      tmp44 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 95
type: ALGORITHM

  assert(heatSource.C[1].T >= 0.0, "Variable violating min constraint: 0.0 <= heatSource.C[1].T, has value: " + String(heatSource.C[1].T, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_95(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,95};
  modelica_boolean tmp45;
  static const MMC_DEFSTRINGLIT(tmp46,72,"Variable violating min constraint: 0.0 <= heatSource.C[1].T, has value: ");
  modelica_string tmp47;
  modelica_metatype tmpMeta48;
  static int tmp49 = 0;
  if(!tmp49)
  {
    tmp45 = GreaterEq((data->simulationInfo->realParameter[20]/* heatSource.C[1].T PARAM */) ,0.0);
    if(!tmp45)
    {
      tmp47 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[20]/* heatSource.C[1].T PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta48 = stringAppend(MMC_REFSTRINGLIT(tmp46),tmp47);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nheatSource.C[1].T >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta48));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/Connectors.mo",4,5,4,49,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nheatSource.C[1].T >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta48));
        }
      }
      tmp49 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 96
type: ALGORITHM

  assert(Paroi3.rhow >= 0.0, "Variable violating min constraint: 0.0 <= Paroi3.rhow, has value: " + String(Paroi3.rhow, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_96(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,96};
  modelica_boolean tmp50;
  static const MMC_DEFSTRINGLIT(tmp51,66,"Variable violating min constraint: 0.0 <= Paroi3.rhow, has value: ");
  modelica_string tmp52;
  modelica_metatype tmpMeta53;
  static int tmp54 = 0;
  if(!tmp54)
  {
    tmp50 = GreaterEq((data->simulationInfo->realParameter[15]/* Paroi3.rhow PARAM */) ,0.0);
    if(!tmp50)
    {
      tmp52 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[15]/* Paroi3.rhow PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta53 = stringAppend(MMC_REFSTRINGLIT(tmp51),tmp52);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nParoi3.rhow >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta53));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/HeatTransfer/HeatExchangerWall.mo",11,3,11,62,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nParoi3.rhow >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta53));
        }
      }
      tmp54 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 97
type: ALGORITHM

  assert(L >= 0.0, "Variable violating min constraint: 0.0 <= L, has value: " + String(L, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_97(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,97};
  modelica_boolean tmp55;
  static const MMC_DEFSTRINGLIT(tmp56,56,"Variable violating min constraint: 0.0 <= L, has value: ");
  modelica_string tmp57;
  modelica_metatype tmpMeta58;
  static int tmp59 = 0;
  if(!tmp59)
  {
    tmp55 = GreaterEq((data->simulationInfo->realParameter[3]/* L PARAM */) ,0.0);
    if(!tmp55)
    {
      tmp57 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[3]/* L PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta58 = stringAppend(MMC_REFSTRINGLIT(tmp56),tmp57);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nL >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta58));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/Solar.mo",2,3,2,46,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nL >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta58));
        }
      }
      tmp59 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 98
type: ALGORITHM

  assert(Paroi3.dM >= 0.0, "Variable violating min constraint: 0.0 <= Paroi3.dM, has value: " + String(Paroi3.dM, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_98(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,98};
  modelica_boolean tmp60;
  static const MMC_DEFSTRINGLIT(tmp61,64,"Variable violating min constraint: 0.0 <= Paroi3.dM, has value: ");
  modelica_string tmp62;
  modelica_metatype tmpMeta63;
  static int tmp64 = 0;
  if(!tmp64)
  {
    tmp60 = GreaterEq((data->simulationInfo->realParameter[10]/* Paroi3.dM PARAM */) ,0.0);
    if(!tmp60)
    {
      tmp62 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[10]/* Paroi3.dM PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta63 = stringAppend(MMC_REFSTRINGLIT(tmp61),tmp62);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nParoi3.dM >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta63));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/HeatTransfer/HeatExchangerWall.mo",21,3,22,24,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nParoi3.dM >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta63));
        }
      }
      tmp64 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 99
type: ALGORITHM

  assert(Paroi3.T0 >= 0.0, "Variable violating min constraint: 0.0 <= Paroi3.T0, has value: " + String(Paroi3.T0, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_99(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,99};
  modelica_boolean tmp65;
  static const MMC_DEFSTRINGLIT(tmp66,64,"Variable violating min constraint: 0.0 <= Paroi3.T0, has value: ");
  modelica_string tmp67;
  modelica_metatype tmpMeta68;
  static int tmp69 = 0;
  if(!tmp69)
  {
    tmp65 = GreaterEq((data->simulationInfo->realParameter[6]/* Paroi3.T0 PARAM */) ,0.0);
    if(!tmp65)
    {
      tmp67 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[6]/* Paroi3.T0 PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta68 = stringAppend(MMC_REFSTRINGLIT(tmp66),tmp67);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nParoi3.T0 >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta68));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Thermal/HeatTransfer/HeatExchangerWall.mo",12,3,13,57,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nParoi3.T0 >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta68));
        }
      }
      tmp69 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 100
type: ALGORITHM

  assert(solarCollector.T0 >= 0.0, "Variable violating min constraint: 0.0 <= solarCollector.T0, has value: " + String(solarCollector.T0, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_100(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,100};
  modelica_boolean tmp70;
  static const MMC_DEFSTRINGLIT(tmp71,72,"Variable violating min constraint: 0.0 <= solarCollector.T0, has value: ");
  modelica_string tmp72;
  modelica_metatype tmpMeta73;
  static int tmp74 = 0;
  if(!tmp74)
  {
    tmp70 = GreaterEq((data->simulationInfo->realParameter[41]/* solarCollector.T0 PARAM */) ,0.0);
    if(!tmp70)
    {
      tmp72 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[41]/* solarCollector.T0 PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta73 = stringAppend(MMC_REFSTRINGLIT(tmp71),tmp72);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nsolarCollector.T0 >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta73));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Solar/Collectors/SolarCollector.mo",25,3,26,57,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nsolarCollector.T0 >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta73));
        }
      }
      tmp74 = 1;
    }
  }
  TRACE_POP
}

/*
equation index: 101
type: ALGORITHM

  assert(solarCollector.rho_glass >= 0.0, "Variable violating min constraint: 0.0 <= solarCollector.rho_glass, has value: " + String(solarCollector.rho_glass, "g"));
*/
OMC_DISABLE_OPT
static void Solar_eqFunction_101(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,101};
  modelica_boolean tmp75;
  static const MMC_DEFSTRINGLIT(tmp76,79,"Variable violating min constraint: 0.0 <= solarCollector.rho_glass, has value: ");
  modelica_string tmp77;
  modelica_metatype tmpMeta78;
  static int tmp79 = 0;
  if(!tmp79)
  {
    tmp75 = GreaterEq((data->simulationInfo->realParameter[49]/* solarCollector.rho_glass PARAM */) ,0.0);
    if(!tmp75)
    {
      tmp77 = modelica_real_to_modelica_string_format((data->simulationInfo->realParameter[49]/* solarCollector.rho_glass PARAM */) , (modelica_string) mmc_strings_len1[103]);
      tmpMeta78 = stringAppend(MMC_REFSTRINGLIT(tmp76),tmp77);
      {
        if (data->simulationInfo->noThrowAsserts) {
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, 0, equationIndexes, "The following assertion has been violated %sat time %f\nsolarCollector.rho_glass >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          infoStreamPrint(LOG_ASSERT, 0, "%s", MMC_STRINGDATA(tmpMeta78));
        } else {
          FILE_INFO info = {"C:/Users/marion/Documents/OM_WD/ThermoSysPro 3.2/Solar/Collectors/SolarCollector.mo",24,3,24,68,0};
          omc_assert_warning(info, "The following assertion has been violated %sat time %f\nsolarCollector.rho_glass >= 0.0", initial() ? "during initialization " : "", data->localData[0]->timeValue);
          omc_assert_warning_withEquationIndexes(info, equationIndexes, MMC_STRINGDATA(tmpMeta78));
        }
      }
      tmp79 = 1;
    }
  }
  TRACE_POP
}
OMC_DISABLE_OPT
void Solar_updateBoundParameters_0(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  Solar_eqFunction_52(data, threadData);
  Solar_eqFunction_53(data, threadData);
  Solar_eqFunction_54(data, threadData);
  Solar_eqFunction_55(data, threadData);
  Solar_eqFunction_56(data, threadData);
  Solar_eqFunction_57(data, threadData);
  Solar_eqFunction_58(data, threadData);
  Solar_eqFunction_59(data, threadData);
  Solar_eqFunction_60(data, threadData);
  Solar_eqFunction_61(data, threadData);
  Solar_eqFunction_62(data, threadData);
  Solar_eqFunction_63(data, threadData);
  Solar_eqFunction_64(data, threadData);
  Solar_eqFunction_65(data, threadData);
  Solar_eqFunction_66(data, threadData);
  Solar_eqFunction_69(data, threadData);
  Solar_eqFunction_70(data, threadData);
  Solar_eqFunction_71(data, threadData);
  Solar_eqFunction_76(data, threadData);
  Solar_eqFunction_37(data, threadData);
  Solar_eqFunction_8(data, threadData);
  Solar_eqFunction_7(data, threadData);
  Solar_eqFunction_6(data, threadData);
  Solar_eqFunction_5(data, threadData);
  Solar_eqFunction_4(data, threadData);
  Solar_eqFunction_3(data, threadData);
  Solar_eqFunction_2(data, threadData);
  Solar_eqFunction_1(data, threadData);
  Solar_eqFunction_87(data, threadData);
  Solar_eqFunction_88(data, threadData);
  Solar_eqFunction_89(data, threadData);
  Solar_eqFunction_90(data, threadData);
  Solar_eqFunction_91(data, threadData);
  Solar_eqFunction_92(data, threadData);
  Solar_eqFunction_93(data, threadData);
  Solar_eqFunction_94(data, threadData);
  Solar_eqFunction_95(data, threadData);
  Solar_eqFunction_96(data, threadData);
  Solar_eqFunction_97(data, threadData);
  Solar_eqFunction_98(data, threadData);
  Solar_eqFunction_99(data, threadData);
  Solar_eqFunction_100(data, threadData);
  Solar_eqFunction_101(data, threadData);
  TRACE_POP
}
OMC_DISABLE_OPT
int Solar_updateBoundParameters(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  (data->simulationInfo->integerParameter[0]/* NSection PARAM */)  = ((modelica_integer) 1);
  data->modelData->integerParameterData[0].time_unvarying = 1;
  (data->simulationInfo->integerParameter[1]/* Paroi3.Ns PARAM */)  = ((modelica_integer) 1);
  data->modelData->integerParameterData[1].time_unvarying = 1;
  (data->simulationInfo->integerParameter[2]/* heatSource.N PARAM */)  = ((modelica_integer) 1);
  data->modelData->integerParameterData[2].time_unvarying = 1;
  (data->simulationInfo->integerParameter[3]/* heatSource.option_temperature PARAM */)  = ((modelica_integer) 1);
  data->modelData->integerParameterData[3].time_unvarying = 1;
  (data->simulationInfo->integerParameter[4]/* solarCollector.Ns PARAM */)  = ((modelica_integer) 1);
  data->modelData->integerParameterData[4].time_unvarying = 1;
  (data->simulationInfo->booleanParameter[0]/* Paroi3.steady_state PARAM */)  = 1;
  data->modelData->booleanParameterData[0].time_unvarying = 1;
  (data->simulationInfo->booleanParameter[1]/* solarCollector.steady_state PARAM */)  = 1;
  data->modelData->booleanParameterData[1].time_unvarying = 1;
  Solar_updateBoundParameters_0(data, threadData);
  TRACE_POP
  return 0;
}

#if defined(__cplusplus)
}
#endif

